@@ -24,7 +24,6 @@ from __future__ import division
 import logging
 import os
 import sys
-import fcntl
 import time
 
 __author__ = 'Alexander Metzner, Michael Gruber, Udo Juettner'
@@ -34,9 +33,11 @@ from select import select
 from shtub import (BASEDIR,
                    EXECUTIONS_FILENAME,
                    CONFIGURED_STUBS_FILENAME,
-                   LOCK_FILENAME,
+                   lock,
+                   unlock,
                    LOG_FILENAME,
                    READ_STDIN_TIMEOUT_IN_SECONDS,
+                   SERIALIZATION_LOCK_FILENAME,
                    deserialize_executions,
                    deserialize_stub_configurations,
                    serialize_as_dictionaries)
@@ -44,27 +45,7 @@ from shtub import (BASEDIR,
 from shtub.execution import Execution
 from shtub.commandinput import CommandInput
 
-
-def lock ():
-    """
-        creates a file lock and blocks if the file lock is already locked.
-    """
-
-    logging.info('Acquire lock.')
-    file_handle = open(LOCK_FILENAME, mode='a')
-    fcntl.flock(file_handle, fcntl.LOCK_EX)
-
-    logging.info('Lock acquired.')
-    return file_handle
-
-
-def unlock (file_handle):
-    """
-        releases the given file lock by closing it.
-    """
-
-    logging.info('Release lock.')
-    file_handle.close()
+global lock_handle
 
 
 def record_execution (execution):
@@ -124,14 +105,14 @@ def dispatch (command_input):
             execution.mark_as_expected()
             record_execution(execution)
             answer = stub_configuration.next_answer()
-
             serialize_as_dictionaries(CONFIGURED_STUBS_FILENAME, stub_configurations)
-
+            unlock(lock_handle)
             if answer.milliseconds_to_wait:
                 time.sleep(answer.milliseconds_to_wait / 1000)
             send_answer(answer)
             return
 
+    unlock(lock_handle)
     logging.error('Given command_input does not fulfill requirements of any stub configuration.')
     sys.exit(255)
 
@@ -158,6 +139,8 @@ def handle_execution ():
 
     if not os.path.exists(BASEDIR):
         os.mkdir(BASEDIR)
+    global lock_handle
+    lock_handle = lock(SERIALIZATION_LOCK_FILENAME)
 
     logging_format = '%(asctime)s %(levelname)5s [%(name)s] process[%(process)d] thread[%(thread)d] - %(message)s'
     logging.basicConfig(filename=LOG_FILENAME,
@@ -173,5 +156,5 @@ def handle_execution ():
     dispatch(command_input)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__': # pragma: no cover
     handle_execution()
